==========
``errors``
==========

.. automodule:: tt.errors


``errors.base`` module
----------------------

.. automodule:: tt.errors.base
    :members:
    :exclude-members: __weakref__


``errors.arguments`` module
---------------------------

.. automodule:: tt.errors.arguments
    :members:


``errors.evaluation`` module
----------------------------

.. automodule:: tt.errors.evaluation
    :members:


``errors.grammar`` module
-------------------------

.. automodule:: tt.errors.grammar
    :members:


``errors.state`` module
-----------------------

.. automodule:: tt.errors.state
    :members:


``errors.symbols`` module
-------------------------

.. automodule:: tt.errors.symbols
    :members:
